// ============================================================================
// ==                                                                        ==
// == AMDiS - Adaptive multidimensional simulations                          ==
// ==                                                                        ==
// ==  http://www.amdis-fem.org                                              ==
// ==                                                                        ==
// ============================================================================
//
// Software License for AMDiS
//
// Copyright (c) 2010 Dresden University of Technology 
// All rights reserved.
// Authors: Simon Vey, Thomas Witkowski et al.
//
// This file is part of AMDiS
//
// See also license.opensource.txt in the distribution.



/** \file PngWriter.h */

#ifndef AMDIS_PNGWRITER_H
#define AMDIS_PNGWRITER_H

#if defined HAVE_PNG

#include "BasisFunction.h"
#include "DataCollector.h"
#include "FileWriter.h"

namespace AMDiS {

  class PngWriter
  {
  public:
    PngWriter(DataCollector<> *dc)
      : dataCollector(dc)
    {
      FUNCNAME("PngWriter::PngWriter()");

      TEST_EXIT(dataCollector->getFeSpace()->getBasisFcts()->getDegree() == 1)
	("PNG Image output only for linear lagrange elements!\n");

      TEST_EXIT(dataCollector->getMesh()->getDim() == 2)
	("PNG image output only for 2D!\n");
    }  

    /// Writes a PNG image file.
    int writeFile(std::string name, int imageType);

  private:
    /// Datacollector with values for the output file.
    DataCollector<>* dataCollector;
  };
}

#endif

#endif
